@@ -75,6 +75,8 @@ def process_xsnt(messages): #[('1648947215933-0', {'snt': 'hello'}), ('164894721
 		if newsnts: 
 			sntdic	= gecsnts(newsnts) 
 			[redis.r.setex(f"gec:{snt}", redis.ttl, gec) for snt, gec in sntdic.items()]
+
+		[redis.r.xdel("xsnt", id) for id,arr in messages]  # added 2022.6.30
 	except Exception as e:
 		print(">>[process_xsnt ex]", e, "\t|", messages, "\t|",  now())
 		exc_type, exc_value, exc_traceback_obj = sys.exc_info()
@@ -91,8 +93,9 @@ def process_xsnts(messages): #[('1648947215933-0', {'snts': '1'}), ('16489472159
 			res		= { snt: gec if gec is not None else sntdic.get(snt,snt) for snt, gec in zip(snts, gecs)}
 			redis.r.lpush(f"suc:{id}", json.dumps(res) )
 			redis.r.expire(f"suc:{id}", redis.ttl) 
+			redis.r.xdel("xsnts", id)  # added 2022.6.30
 		except Exception as e:
-			print ("parse err:", e, id, arr) 
+			print ("process_xsnts parse err:", e, id, arr) 
 			redis.r.lpush(f"err:{id}", json.dumps(arr))
 			redis.r.expire(f"err:{id}", redis.ttl) 
 			redis.r.setex(f"exception:{id}", redis.ttl, str(e))
