@@ -66,7 +66,7 @@ def from_docbin(bs):
 	return list(spacy.tokens.DocBin().from_bytes(bs).get_docs(spacy.nlp.vocab))[0] if bs else None
 
 if not hasattr(spacy, 'nlp'):
-	spacy.nlp		= spacy.load('en_core_web_sm') 
+	spacy.nlp		= spacy.load('en_core_web_lg') # 3.4.1
 	spacy.tobs		= to_docbin # for old codes
 	spacy.frombs	= from_docbin
 	spacy.nlp.tokenizer = custom_tokenizer(spacy.nlp)	#nlp.tokenizer.infix_finditer = infix_re.finditer
