@@ -3,7 +3,7 @@ import spacy , traceback, sys
 from spacy.matcher import Matcher,DependencyMatcher
 from collections import	Counter, defaultdict
 
-if not hasattr(spacy,'nlp'): spacy.nlp	= spacy.load('en_core_web_sm') #if not 'nlp' in dir(): nlp	= spacy.load('en_core_web_sm')
+if not hasattr(spacy,'nlp'): spacy.nlp	= spacy.load('en_core_web_lg') #if not 'nlp' in dir(): nlp	= spacy.load('en_core_web_sm')
 vp_span = lambda doc,ibeg,iend: doc[ibeg].lemma_ + " " + doc[ibeg+1:iend].text.lower()
 
 def new_matcher(patterns, name='pat'):
