@@ -63,6 +63,7 @@ config = {
 			  "analyzer": {
 				"postag_ana": {"filter": ["lowercase","postag_filter", "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" },
 				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
+				"path_ana3": {"type": "custom", "tokenizer": "path-tokenizer3"},
 				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
 				"err_ana": {"type": "custom",  "tokenizer": "path-tokenizer1"  },
 				"chunk_ana": {"type": "custom", "tokenizer": "path-tokenizer2" },
@@ -72,6 +73,7 @@ config = {
 				"path-tokenizer": { "type": "path_hierarchy",  "delimiter": "/" },
 				"path-tokenizer1": {"type": "path_hierarchy",  "delimiter": "|" },
 				"path-tokenizer2": {"type": "path_hierarchy",  "delimiter": "/" },
+				"path-tokenizer3": {"type": "path_hierarchy",  "delimiter": ":" },
 				"feedback-tokenizer": { "type": "path_hierarchy",  "delimiter": "." }
 				}
 			},
@@ -83,7 +85,8 @@ config = {
 			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
 			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
-			"kps": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
+			"kps": { "type": "text", "analyzer": "path_ana3" ,"fielddata":"true" },
+			"pterm": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" }, # path term
 			"postag": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"skenp": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"sentgram": { "type": "text", "analyzer": "postag_ana","fielddata":"true"}, # simple_complex_headpp compound_question_itis_svo
