@@ -27,6 +27,7 @@ from nltk_fastapi	import *
 from hnswlib_fastapi	import *
 from kpsi_fastapi	import *
 from echart_fastapi	import *
+from flair_fastapi	import *
 
 #if os.getenv('eshost','') : from es_fastapi import * 
 if os.getenv('rhost','') : from uviredis import * 
@@ -45,7 +46,7 @@ async def svnup():
 
 def run(port, reload:bool=False): 
 	''' python3 __main__.py 8000 --reload true '''
-	uvicorn.run("__main__:app", host='0.0.0.0', port=port, reload=reload) 	#uvicorn.run(app, host='0.0.0.0', port=port, reload=reload)
+	uvicorn.run("__main__:app", host='0.0.0.0', port=port, reload=reload) 	
 
 if __name__ == '__main__':
 	import fire
