@@ -110,6 +110,56 @@ def dsk_wrapper(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True,
 			snt['feedback'] = [ v for k,v in snt.get('feedback',{}).items()]
 	return dsk 
 
+@app.post('/dsk/docjson', tags=["dsk"])
+def dsk_docjson(docjson:dict={'text': 'I am a boy.',
+ 'ents': [],
+ 'sents': [{'start': 0, 'end': 11}],
+ 'tokens': [{'id': 0,
+   'start': 0,
+   'end': 1,
+   'tag': 'PRP',
+   'pos': 'PRON',
+   'morph': 'Case=Nom|Number=Sing|Person=1|PronType=Prs',
+   'lemma': 'I',
+   'dep': 'nsubj',
+   'head': 1},
+  {'id': 1,
+   'start': 2,
+   'end': 4,
+   'tag': 'VBP',
+   'pos': 'AUX',
+   'morph': 'Mood=Ind|Person=1|Tense=Pres|VerbForm=Fin',
+   'lemma': 'be',
+   'dep': 'ROOT',
+   'head': 1},
+  {'id': 2,
+   'start': 5,
+   'end': 10,
+   'tag': 'NN',
+   'pos': 'NOUN',
+   'morph': 'Number=Sing',
+   'lemma': 'boy',
+   'dep': 'attr',
+   'head': 1},
+  {'id': 3,
+   'start': 10,
+   'end': 11,
+   'tag': '.',
+   'pos': 'PUNCT',
+   'morph': 'PunctType=Peri',
+   'lemma': '.',
+   'dep': 'punct',
+   'head': 1}]}, asdsk:bool=True, timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
+	''' 2022.8.4 '''
+	from spacy.tokens import Doc
+	tdoc	= Doc(spacy.nlp.vocab).from_json(docjson)
+	snts	= [snt.text for snt in tdoc.sents]
+	sntdic	= requests.post(f"http://{gechost}/getgecs", params={"timeout":timeout}, json=snts).json ()
+	docs	= [snt.as_doc() for snt in tdoc.sents]
+	input	= mkf_input(snts, docs, spacy.nlp.tokenizer, sntdic)
+	dsk		= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps({"snts":input, "rid":"10"} if asdsk else input).encode("utf-8")}).json()
+	return dsk 
+
 @app.get('/dsk/fds', tags=["dsk"])
 def dsk_fds(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
 	''' mkf JSONEachRow '''
@@ -121,7 +171,7 @@ def dsk_fds(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechos
 
 	def _getfd(mkf): 	
 		res = 	{"snt": mkf.get('meta',{}).get('snt','')}
-		for k,v in mkf.get('feedback','').items(): 
+		for k,v in mkf.get('feedback',{}).items(): 
 			res.update( {"cate": v.get('cate',''), "short_msg": v.get('short_msg','') } )
 		return res
 
@@ -131,8 +181,9 @@ def dsk_fds(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechos
 def dsk_mkf(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
 	return dsk_wrapper(essay_or_snts, asdsk=False, timeout=timeout, gechost=gechost, dskhost=dskhost)
 
-if __name__ == '__main__': #uvicorn.run(app, host='0.0.0.0', port=80)
-	print ( dsk_fds()) 
+if __name__ == '__main__': 
+	print ( dsk_docjson(), flush=True) 
+	uvicorn.run(app, host='0.0.0.0', port=80)
 	#print (dsk_wrapper("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", JSONEachRow=True))
 	#print (sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity."))
 
