@@ -20,6 +20,9 @@ def rows(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos !
 		[row.update({"cp":cp}) for row in si]
 	return si #return [  dict(zip([ ar['name'] for ar in res['columns'] ] , ar)) for ar in res.get('rows',[]) ] 
 
+sntsum	= lambda cp: rows(f"select count(*) cnt from {cp} where type = 'snt'", raw=True )[0][0] 
+lexsum	= lambda cp: rows(f"select count(*) cnt from {cp} where type = 'tok'", raw=True )[0][0] 
+
 @app.get('/es/groupby', tags=["es"])
 def es_groupby(key:str="lem", index:str='gzjc', where:str="type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10", eshost:str="es.corpusly.com:9200"):
 	''' # select snt from dic where type = 'snt' and kp = 'book_VERB' limit 2, 2022.8.4 '''
@@ -61,7 +64,16 @@ def corpus_stats(names:str=None, types:str="doc,snt,np,tok,trp,vp", eshost:str="
 	return [ dict( dict(rows(f"select type, count(*) cnt from {name} where type in ('{types}') group by type")), **{"name":name} ) for name in names]
 
 @app.get("/es/phrase", tags=["es"])
-def match_phrase(phrase:str='opened the box', eshost:str="es.corpusly.com:9200", cp:str='clec', topk:int=10): 	return requests.post(f"http://{eshost}/{cp}/_search/", json={"query": {  "match_phrase": { "snt": phrase }  } , "size": topk}).json()
+def match_phrase(phrase:str='opened the box', eshost:str="es.corpusly.com:9200", cp:str='clec', topk:int=10): 	
+	return requests.post(f"http://{eshost}/{cp}/_search/", json={"query": {  "match_phrase": { "snt": phrase }  } , "size": topk}).json()
+@app.get("/es/phrase_num", tags=["es"])
+def phrase_num(phrase:str='opened the box',  eshost:str="es.corpusly.com:9200",cp:str='clec', topk:int=10): 
+	return match_phrase(phrase, eshost, cp, topk)["hits"]["total"]["value"]
+
+@app.get("/es/mf", tags=["es"])
+def corpus_mf(cps:str="gzjc,clec", w:str="considered", topk:int=3, eshost:str="es.corpusly.com:9200"):
+	dic =  {cp: round(1000000 * phrase_num(w, cp=cp) / (sntsum(cp)+0.1), 2 ) for cp in cps.strip().split(',') }
+	return [ {"cp":cp, "mf":mf } for cp,mf in dic.items()]
 
 @app.get("/es/newindex", tags=["es"])
 def new_index(index:str='testidx', eshost:str="es.corpusly.com:9200"):
@@ -183,9 +195,8 @@ async def create_upload_file(index:str="shexam", rid:int=0, file: UploadFile = F
 	return indexdoc({'essay_or_snts':content.decode().strip(),'rid':rid, 'uid':file.filename}, index=index, refresh_index=refresh_index)  
 
 if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
-	#print ( rows(sum_query="select count(*) from gzjc where type='snt'") )
-	print ( es_groupby(), flush=True)  #refresh_index=True
-	uvicorn.run(app, host='0.0.0.0', port=80)
+	print ( corpus_kwic(), flush=True)  #refresh_index=True
+	#uvicorn.run(app, host='0.0.0.0', port=80)
 
 '''
 POST /_sql
