@@ -23,6 +23,13 @@ def get_kenlm_flue(snt:str="I love you|I like you",name:str="nyt5", sepa:str="|"
 	model = _model(name)
 	return [ {"snt": s, "flue": round(kenlm_flue(s, model), 4)} for s in snt.strip().split(sepa)]
 
+@app.get('/kenlm/flue/single', tags=["kenlm"])
+def kenlm_flue_single(body:str="Parents * much importance to education.", star:str='*', options:str="attach,pay,link,apply", sepa:str=",", name:str='nyt5', asrows:bool=False): 
+	'''  2022.8.6 '''
+	model = _model(name)
+	rows  = [   (option, round(kenlm_flue(body.replace(star, option), model), 4) )  for option in options.strip().split(sepa) ] 
+	return rows if asrows else [  {"word":row[0], "flue": row[1] }  for row in rows ]
+
 @app.get('/kenlm/score', tags=["kenlm"])
 def kenlm_snt_score(snt:str="I love you|I like you", name:str="nyt5", sepa:str="|", fullscore:bool=False): 
 	''' name: zkenlm/nyt5 '''
@@ -47,7 +54,7 @@ def fluedel(snt:str="I love you", wordidx:int=0, name:str="nyt5"):
 	return flue_del(snt, wordidx, _model(name))
 
 if __name__ == '__main__':
-	print ( get_kenlm_flue()) 
+	print ( kenlm_flue_single(asrows=True)) 
 	#uvicorn.run(app, host='0.0.0.0', port=80)
 
 '''
